parade.command.feature package
==============================

Submodules
----------

parade.command.feature.install module
-------------------------------------

.. automodule:: parade.command.feature.install
    :members:
    :undoc-members:
    :show-inheritance:

parade.command.feature.search module
------------------------------------

.. automodule:: parade.command.feature.search
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: parade.command.feature
    :members:
    :undoc-members:
    :show-inheritance:
